@@ -10,9 +10,5 @@ class HeaderToLabelFilter(logging.Filter):
             for label in getattr(settings, LOG_LABEL_REQUEST_SETTING):
                 header_value = getattr(local, label, DEFAULT_HEADER_VALUE)
                 setattr(record, label, header_value)
-                if isinstance(record.msg, dict):
-                    if "_log_identifier" not in record.msg:
-                        record.msg["_log_identifier"] = dict()
-                    record.msg["_log_identifier"][label] = header_value
         return True
 
