@@ -86,8 +86,8 @@ class Utils:
                 if re.search(pattern, body):
                     try:
                         body = re.sub(pattern, replacement, body)
-                    except re.error as ex:
-                        logger.error("Unable to obfuscate the body: {}".format(str(ex)))
+                    except Exception as ex:
+                        logger.error("Unable to obfuscate the body for the pattern '{}': {}".format(pattern, str(ex)))
 
         return body
 
@@ -100,8 +100,8 @@ class Utils:
                 if re.search(pattern, response):
                     try:
                         response = re.sub(pattern, replacement, response)
-                    except re.error as ex:
-                        logger.error("Unable to obfuscate the response: {}".format(str(ex)))
+                    except Exception as ex:
+                        logger.error("Unable to obfuscate the body for the pattern '{}': {}".format(pattern, str(ex)))
 
         return response
 
@@ -113,7 +113,7 @@ class Utils:
                 if re.search(pattern, url):
                     try:
                         url = re.sub(pattern, replacement, url)
-                    except re.error as ex:
-                        logger.error("Unable to obfuscate the url: {}".format(str(ex)))
+                    except Exception as ex:
+                        logger.error("Unable to obfuscate the body for the pattern '{}': {}".format(pattern, str(ex)))
 
         return url
